This is a linear maths library that utilizes pyopencl to send calculations to the GPU. 
It is intended to be used as an underlying library for ML libraries, or graphics engine libraries


To download and incorporate this library into your project do the following:
    Create a python virtual environment at the base level of your project directory
    Ensure pip is the updated to the latest version
    Make sure to be in the base directory of your project and run your activate project
    Run:
        pip install --index-url https://pypi.org/simple/ ParallelLinear-CraigR8806


After completing the above steps, you should be able to use the library within your project
